==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/form-view/EditFormView.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/form-view/EditFormView.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', 'frontend-js-react-web$react-dom', '../../AppContext.es', '../../components/control-menu/ControlMenu.es', './CustomObjectSidebar.es', './DataLayoutBuilderDragAndDrop.es', './DataLayoutBuilderSidebar.es', './FormViewContextProvider.es', './FormViewUpperToolbar.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactDom = require("frontend-js-react-web$react-dom");

  var _AppContext = require("../../AppContext.es");

  var _ControlMenu = require("../../components/control-menu/ControlMenu.es");

  var _CustomObjectSidebar = _interopRequireDefault(require("./CustomObjectSidebar.es"));

  var _DataLayoutBuilderDragAndDrop = _interopRequireDefault(require("./DataLayoutBuilderDragAndDrop.es"));

  var _DataLayoutBuilderSidebar = _interopRequireDefault(require("./DataLayoutBuilderSidebar.es"));

  var _FormViewContextProvider = _interopRequireDefault(require("./FormViewContextProvider.es"));

  var _FormViewUpperToolbar = _interopRequireDefault(require("./FormViewUpperToolbar.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }return target;
    };return _extends.apply(this, arguments);
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  var parseProps = function parseProps(_ref) {
    var dataDefinitionId = _ref.dataDefinitionId,
        dataLayoutId = _ref.dataLayoutId,
        props = _objectWithoutProperties(_ref, ["dataDefinitionId", "dataLayoutId"]);

    return _objectSpread({}, props, {
      dataDefinitionId: Number(dataDefinitionId),
      dataLayoutId: Number(dataLayoutId)
    });
  };

  var FormViewControlMenu = function FormViewControlMenu(_ref2) {
    var backURL = _ref2.backURL,
        dataLayoutId = _ref2.dataLayoutId;
    var title = Liferay.Language.get('new-form-view');

    if (dataLayoutId > 0) {
      title = Liferay.Language.get('edit-form-view');
    }

    return _react["default"].createElement(_ControlMenu.ControlMenuBase, {
      backURL: backURL,
      title: title,
      url: location.href
    });
  };

  var EditFormView = function EditFormView(props) {
    var _parseProps = parseProps(props),
        customObjectSidebarElementId = _parseProps.customObjectSidebarElementId,
        dataDefinitionId = _parseProps.dataDefinitionId,
        dataLayoutBuilder = _parseProps.dataLayoutBuilder,
        dataLayoutBuilderElementId = _parseProps.dataLayoutBuilderElementId,
        dataLayoutId = _parseProps.dataLayoutId,
        newCustomObject = _parseProps.newCustomObject;

    var _useContext = (0, _react.useContext)(_AppContext.AppContext),
        basePortletURL = _useContext.basePortletURL;

    var backURL = "".concat(basePortletURL, "/#/custom-object/").concat(dataDefinitionId, "/form-views");

    if (newCustomObject) {
      backURL = basePortletURL;
    }

    return _react["default"].createElement(_FormViewContextProvider["default"], {
      dataDefinitionId: dataDefinitionId,
      dataLayoutBuilder: dataLayoutBuilder,
      dataLayoutId: dataLayoutId
    }, _react["default"].createElement(FormViewControlMenu, {
      backURL: backURL,
      dataLayoutId: dataLayoutId
    }), _react["default"].createElement(_FormViewUpperToolbar["default"], {
      newCustomObject: newCustomObject
    }), (0, _reactDom.createPortal)(_react["default"].createElement(_CustomObjectSidebar["default"], {
      customObjectSidebarElementId: customObjectSidebarElementId
    }), document.querySelector("#".concat(customObjectSidebarElementId))), _react["default"].createElement(_DataLayoutBuilderSidebar["default"], {
      dataLayoutBuilder: dataLayoutBuilder,
      dataLayoutBuilderElementId: dataLayoutBuilderElementId
    }), _react["default"].createElement(_DataLayoutBuilderDragAndDrop["default"], {
      dataLayoutBuilder: dataLayoutBuilder
    }));
  };

  var _default = function _default(_ref3) {
    var dataLayoutBuilderId = _ref3.dataLayoutBuilderId,
        props = _objectWithoutProperties(_ref3, ["dataLayoutBuilderId"]);

    var _useState = (0, _react.useState)(),
        _useState2 = _slicedToArray(_useState, 2),
        dataLayoutBuilder = _useState2[0],
        setDataLayoutBuilder = _useState2[1];

    if (!dataLayoutBuilder) {
      Liferay.componentReady(dataLayoutBuilderId).then(setDataLayoutBuilder);
    }

    return dataLayoutBuilder ? _react["default"].createElement(EditFormView, _extends({
      dataLayoutBuilder: dataLayoutBuilder
    }, props)) : null;
  };

  exports["default"] = _default;
  //# sourceMappingURL=EditFormView.es.js.map
});
//# sourceMappingURL=EditFormView.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/form-view/EditFormView.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/form-view/EditFormView.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', 'frontend-js-react-web$react-dnd', 'frontend-js-react-web$react-dnd-html5-backend', 'frontend-js-react-web$react-dom', '../../AppContext.es', '../../components/control-menu/ControlMenu.es', './CustomObjectSidebar.es', './FormViewContextProvider.es', './FormViewUpperToolbar.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactDnd = require("frontend-js-react-web$react-dnd");

  var _reactDndHtml5Backend = _interopRequireDefault(require("frontend-js-react-web$react-dnd-html5-backend"));

  var _reactDom = require("frontend-js-react-web$react-dom");

  var _AppContext = require("../../AppContext.es");

  var _ControlMenu = require("../../components/control-menu/ControlMenu.es");

  var _CustomObjectSidebar = _interopRequireDefault(require("./CustomObjectSidebar.es"));

  var _FormViewContextProvider = _interopRequireDefault(require("./FormViewContextProvider.es"));

  var _FormViewUpperToolbar = _interopRequireDefault(require("./FormViewUpperToolbar.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _extends() {
    _extends = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }return target;
    };return _extends.apply(this, arguments);
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  var parseProps = function parseProps(_ref) {
    var dataDefinitionId = _ref.dataDefinitionId,
        dataLayoutId = _ref.dataLayoutId,
        props = _objectWithoutProperties(_ref, ["dataDefinitionId", "dataLayoutId"]);

    return _objectSpread({}, props, {
      dataDefinitionId: Number(dataDefinitionId),
      dataLayoutId: Number(dataLayoutId)
    });
  };

  var FormViewControlMenu = function FormViewControlMenu(_ref2) {
    var backURL = _ref2.backURL,
        dataLayoutId = _ref2.dataLayoutId;
    var title = Liferay.Language.get('new-form-view');

    if (dataLayoutId > 0) {
      title = Liferay.Language.get('edit-form-view');
    }

    return _react["default"].createElement(_ControlMenu.ControlMenuBase, {
      backURL: backURL,
      title: title,
      url: location.href
    });
  };

  var EditFormView = function EditFormView(props) {
    var _parseProps = parseProps(props),
        customObjectSidebarElementId = _parseProps.customObjectSidebarElementId,
        dataDefinitionId = _parseProps.dataDefinitionId,
        dataLayoutBuilder = _parseProps.dataLayoutBuilder,
        dataLayoutId = _parseProps.dataLayoutId,
        newCustomObject = _parseProps.newCustomObject;

    var _useContext = (0, _react.useContext)(_AppContext.AppContext),
        basePortletURL = _useContext.basePortletURL;

    var backURL = "".concat(basePortletURL, "/#/custom-object/").concat(dataDefinitionId, "/form-views");

    if (newCustomObject) {
      backURL = basePortletURL;
    }

    return _react["default"].createElement(_reactDnd.DndProvider, {
      backend: _reactDndHtml5Backend["default"]
    }, _react["default"].createElement(_FormViewContextProvider["default"], {
      dataDefinitionId: dataDefinitionId,
      dataLayoutBuilder: dataLayoutBuilder,
      dataLayoutId: dataLayoutId
    }, _react["default"].createElement(FormViewControlMenu, {
      backURL: backURL,
      dataLayoutId: dataLayoutId
    }), _react["default"].createElement(_FormViewUpperToolbar["default"], {
      newCustomObject: newCustomObject
    }), (0, _reactDom.createPortal)(_react["default"].createElement(_CustomObjectSidebar["default"], null), document.querySelector("#".concat(customObjectSidebarElementId)))));
  };

  var _default = function _default(_ref3) {
    var dataLayoutBuilderId = _ref3.dataLayoutBuilderId,
        props = _objectWithoutProperties(_ref3, ["dataLayoutBuilderId"]);

    var _useState = (0, _react.useState)(),
        _useState2 = _slicedToArray(_useState, 2),
        dataLayoutBuilder = _useState2[0],
        setDataLayoutBuilder = _useState2[1];

    if (!dataLayoutBuilder) {
      Liferay.componentReady(dataLayoutBuilderId).then(setDataLayoutBuilder);
    }

    return dataLayoutBuilder ? _react["default"].createElement(EditFormView, _extends({
      dataLayoutBuilder: dataLayoutBuilder
    }, props)) : null;
  };

  exports["default"] = _default;
  //# sourceMappingURL=EditFormView.es.js.map
});
//# sourceMappingURL=EditFormView.es.js.map
